<?php

declare(strict_types=1);

namespace Drupal\inactive_user_management\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Queue\QueueFactory;
use Drupal\Core\Queue\QueueWorkerManagerInterface;
use Drupal\Core\State\StateInterface;
use Drupal\inactive_user_management\Notification\InactiveUserNotification;
use Drupal\inactive_user_management\Settings\NotificationSettings;

/**
 * Cron hook implementations for inactive user management.
 */
class InactiveUserManagementHooks {

  /**
   * The State object.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected StateInterface $state;

  /**
   * The InactiveUserNotification object.
   *
   * @var \Drupal\inactive_user_management\Notification\InactiveUserNotification
   */
  protected InactiveUserNotification $userNotification;

  /**
   * The QueueFactory object.
   *
   * @var \Drupal\Core\Queue\QueueFactory
   */
  protected QueueFactory $queueFactory;

  /**
   * The QueueWorkerManager object.
   *
   * @var \Drupal\Core\Queue\QueueWorkerManagerInterface
   */
  protected QueueWorkerManagerInterface $queueWorker;

  public function __construct(StateInterface $state, InactiveUserNotification $inactive_user_notification, QueueFactory $queue, QueueWorkerManagerInterface $queue_worker) {
    $this->state = $state;
    $this->userNotification = $inactive_user_notification;
    $this->queueFactory = $queue;
    $this->queueWorker = $queue_worker;
  }

  /**
   * Implements hook_cron().
   */
  #[Hook('cron')]
  public function cron(): void {
    $emailState = $this->state->get(NotificationSettings::NOTIFICATION_SETTINGS_PREFIX . '_enabled');
    if ($emailState) {
      $this->userNotification->sendNotificationToInactiveUsers();
    }
  }

}
