<?php

declare(strict_types=1);

namespace Drupal\inactive_user_management\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\Attribute\QueueWorker;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\inactive_user_management\Notification\InactiveUserNotification;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Executes inactive user notification queue tasks.
 */
#[QueueWorker(
  id: 'inactive_user_notification',
  title: new TranslatableMarkup('Inactive User Notification'),
  cron: ['time' => 60],
)]
class NotificationSender extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The InactiveUserNotification object.
   *
   * @var \Drupal\inactive_user_management\Notification\InactiveUserNotification
   */
  private InactiveUserNotification $inactiveUserNotification;

  /**
   * {@inheritDoc}
   */
  public function processItem($data): void {
    if (!empty($data)) {
      $this->inactiveUserNotification->sendNotification($data['user']);
    }
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    /** @var \Drupal\inactive_user_management\Notification\InactiveUserNotification $inactiveUserNotification */
    $inactiveUserNotification = $container->get('inactive_user_notification');
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $inactiveUserNotification
    );
  }

  /**
   * {@inheritDoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, InactiveUserNotification $inactive_user_notification) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->inactiveUserNotification = $inactive_user_notification;
  }

}
